<?php

namespace Bixo\Recomentations\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Recomentations\Http\Requests\RecomentationRequest;
use Bixo\Recomentations\Interfaces\RecomentationRepositoryInterface;
use Bixo\Recomentations\Models\Recomentation;
use Bixo\Recomentations\Forms\Recomentation as Form;

/**
 * APIController  class for recomentation.
 */
class RecomentationAPIController extends BaseController
{

    /**
     * Initialize recomentation resource controller.
     *
     * @param type RecomentationRepositoryInterface $recomentation
     *
     * @return null
     */
    public function __construct(RecomentationRepositoryInterface $recomentation)
    {
        parent::__construct();
        $this->repository = $recomentation;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Recomentations\Repositories\Criteria\RecomentationResourceCriteria::class);
    }

    /**
     * Display a list of recomentation.
     *
     * @return Response
     */
    public function index(RecomentationRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Recomentations\Repositories\Presenter\RecomentationPresenter::class)
            ->paginate();
    }

    /**
     * Display recomentation.
     *
     * @param Request $request
     * @param Model   $recomentation
     *
     * @return Response
     */
    public function show(RecomentationRequest $request, Recomentation $recomentation)
    {
        return $recomentation->setPresenter(\Bixo\Recomentations\Repositories\Presenter\RecomentationListPresenter::class);
        ;
    }

    /**
     * Create new recomentation.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RecomentationRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('recomentations::recomentation.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('recomentations/recomentation/' . $recomentation->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('recomentations/recomentation');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the recomentation.
     *
     * @param Request $request
     * @param Model   $recomentation
     *
     * @return Response
     */
    public function update(RecomentationRequest $request, Recomentation $recomentation)
    {
        try {
            $data = $request->all();

            $recomentation->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('recomentations::recomentation.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('recomentations/recomentation/' . $recomentation->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('recomentations/recomentation/' . $recomentation->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the recomentation.
     *
     * @param Model   $recomentation
     *
     * @return Response
     */
    public function destroy(RecomentationRequest $request, Recomentation $recomentation)
    {
        try {
            $recomentation->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('recomentations::recomentation.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('recomentations/recomentation/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('recomentations/recomentation/' . $recomentation->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
