<?php

namespace Bixo\Recomentations\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Bixo\Recomentations\Http\Requests\RecomentationRequest;
use Bixo\Recomentations\Models\Recomentation;

/**
 * Admin web controller class.
 */
class RecomentationWorkflowController extends BaseController
{

    /**
     * Workflow controller function for recomentation.
     *
     * @param Model   $recomentation
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(RecomentationRequest $request, Recomentation $recomentation, $step)
    {

        try {

            $recomentation->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('recomentations::recomentation.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/recomentation/recomentation/' . $recomentation->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/recomentation/recomentation/' . $recomentation->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for recomentation.
     *
     * @param Model   $recomentation
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Recomentation $recomentation, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $recomentation->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('recomentations::recomentation.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('recomentations::admin.recomentation.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('recomentations::admin.recomentation.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('recomentations::admin.recomentation.message', $data)->render();

        }

    }
}
