<?php

namespace Bixo\Recomentations\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Recomentations\Models\Recomentation;

class RecomentationPolicy
{

    /**
     * Determine if the given user can view the recomentation.
     *
     * @param UserPolicy $user
     * @param Recomentation $recomentation
     *
     * @return bool
     */
    public function view(UserPolicy $user, Recomentation $recomentation)
    {
        if ($user->canDo('recomentations.recomentation.view') && $user->isAdmin()) {
            return true;
        }

        return $recomentation->user_id == user_id() && $recomentation->user_type == user_type();
    }

    /**
     * Determine if the given user can create a recomentation.
     *
     * @param UserPolicy $user
     * @param Recomentation $recomentation
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('recomentations.recomentation.create');
    }

    /**
     * Determine if the given user can update the given recomentation.
     *
     * @param UserPolicy $user
     * @param Recomentation $recomentation
     *
     * @return bool
     */
    public function update(UserPolicy $user, Recomentation $recomentation)
    {
        if ($user->canDo('recomentations.recomentation.edit') && $user->isAdmin()) {
            return true;
        }

        return $recomentation->user_id == user_id() && $recomentation->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given recomentation.
     *
     * @param UserPolicy $user
     * @param Recomentation $recomentation
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Recomentation $recomentation)
    {
        return $recomentation->user_id == user_id() && $recomentation->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given recomentation.
     *
     * @param UserPolicy $user
     * @param Recomentation $recomentation
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Recomentation $recomentation)
    {
        if ($user->canDo('recomentations.recomentation.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given recomentation.
     *
     * @param UserPolicy $user
     * @param Recomentation $recomentation
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Recomentation $recomentation)
    {
        if ($user->canDo('recomentations.recomentation.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
