<?php

namespace Bixo\Recomentations\Providers;

use Illuminate\Support\ServiceProvider;

class RecomentationsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'recomentations');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'recomentations');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerRecomentations();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerRecomentations()
    {
        $this->app->bind('recomentations', function($app) {
            return new Recomentations($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Recomentations', 'Lavalite\Recomentations\Facades\Recomentations');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('bixo.recomentations', function ($app) {
            return $this->app->make('Bixo\Recomentations\Recomentations');
        });

                // Bind Recomentation to repository
        $this->app->bind(
            'Bixo\Recomentations\Interfaces\RecomentationRepositoryInterface',
            \Bixo\Recomentations\Repositories\Eloquent\RecomentationRepository::class
        );

        $this->app->register(\Bixo\Recomentations\Providers\AuthServiceProvider::class);
                $this->app->register(\Bixo\Recomentations\Providers\EventServiceProvider::class);
        
        $this->app->register(\Bixo\Recomentations\Providers\RouteServiceProvider::class);
                // $this->app->register(\Bixo\Recomentations\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and recomentations's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.recomentations'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeRecomentations::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.recomentations'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bixo/recomentations.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/recomentations')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/recomentations')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
