<?php

namespace Bixo\Recomentations\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Bixo\Recomentations\Models\Recomentation;

class RecomentationAction
{
    /**
     * Perform the complete action.
     *
     * @param Recomentation $recomentation
     *
     * @return Recomentation
     */
    public function complete(Recomentation $recomentation)
    {
        try {
            $recomentation->status = 'complete';
            return $recomentation->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Recomentation $recomentation
     *
     * @return Recomentation
     */public function verify(Recomentation $recomentation)
    {
        try {
            $recomentation->status = 'verify';
            return $recomentation->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Recomentation $recomentation
     *
     * @return Recomentation
     */public function approve(Recomentation $recomentation)
    {
        try {
            $recomentation->status = 'approve';
            return $recomentation->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Recomentation $recomentation
     *
     * @return Recomentation
     */public function publish(Recomentation $recomentation)
    {
        try {
            $recomentation->status = 'publish';
            return $recomentation->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Recomentation $recomentation
     *
     * @return Recomentation
     */
    public function archive(Recomentation $recomentation)
    {
        try {
            $recomentation->status = 'archive';
            return $recomentation->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Recomentation $recomentation
     *
     * @return Recomentation
     */
    public function unpublish(Recomentation $recomentation)
    {
        try {
            $recomentation->status = 'unpublish';
            return $recomentation->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
