<?php

namespace Bixo\Recomentations\Workflow;

use Bixo\Recomentations\Models\Recomentation;
use Validator;

class RecomentationValidator
{

    /**
     * Determine if the given recomentation is valid for complete status.
     *
     * @param Recomentation $recomentation
     *
     * @return bool / Validator
     */
    public function complete(Recomentation $recomentation)
    {
        return Validator::make($recomentation->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given recomentation is valid for verify status.
     *
     * @param Recomentation $recomentation
     *
     * @return bool / Validator
     */
    public function verify(Recomentation $recomentation)
    {
        return Validator::make($recomentation->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given recomentation is valid for approve status.
     *
     * @param Recomentation $recomentation
     *
     * @return bool / Validator
     */
    public function approve(Recomentation $recomentation)
    {
        return Validator::make($recomentation->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given recomentation is valid for publish status.
     *
     * @param Recomentation $recomentation
     *
     * @return bool / Validator
     */
    public function publish(Recomentation $recomentation)
    {
        return Validator::make($recomentation->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given recomentation is valid for archive status.
     *
     * @param Recomentation $recomentation
     *
     * @return bool / Validator
     */
    public function archive(Recomentation $recomentation)
    {
        return Validator::make($recomentation->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given recomentation is valid for unpublish status.
     *
     * @param Recomentation $recomentation
     *
     * @return bool / Validator
     */
    public function unpublish(Recomentation $recomentation)
    {
        return Validator::make($recomentation->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
